import os
import sys
import subprocess

def run_fosum():
    package_dir = os.path.dirname(os.path.abspath(__file__))
    binary_path = os.path.join(package_dir, 'bin', 'fosum')
    if not os.path.exists(binary_path):
        sys.exit(f"Error: Binary not found at {binary_path}")
    subprocess.run([binary_path] + sys.argv[1:])



from setuptools import setup, find_packages

setup(
    name="fosum",
    version="0.3.0",
    description="A simple tool that summarizes file folders. Useful for passing context to LLMs",
    author="Rohan Adwankar",
    author_email="rohan.adwankar@gmail.com",
    license="MIT",
    packages=find_packages(),
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "fosum = fosum:run_fosum",
        ],
    },
)